@@ -185,7 +185,7 @@ must_be_attached = [
     "TNtuple",
     "TNtupleD",
     "TTreeSQL",
-    "ROOT::Experimental::RNTuple",
+    "ROOT::RNTuple",
 ]
 
 
